emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master d6a2754 2/2: ; Fix more typos


From: Stefan Kangas
Subject: master d6a2754 2/2: ; Fix more typos
Date: Sat, 3 Oct 2020 06:57:14 -0400 (EDT)

branch: master
commit d6a2754348f57883036c0f35f0a880b7817e6bc1
Author: Stefan Kangas <stefan@marxist.se>
Commit: Stefan Kangas <stefan@marxist.se>

    ; Fix more typos
---
 doc/lispref/tips.texi                | 2 +-
 doc/misc/edt.texi                    | 2 +-
 doc/misc/emacs-mime.texi             | 2 +-
 doc/misc/gnus.texi                   | 2 +-
 etc/compilation.txt                  | 2 +-
 lisp/cedet/srecode/fields.el         | 2 +-
 lisp/completion.el                   | 2 +-
 lisp/find-file.el                    | 4 ++--
 lisp/international/characters.el     | 2 +-
 lisp/menu-bar.el                     | 2 +-
 lisp/progmodes/perl-mode.el          | 2 +-
 m4/pkg.m4                            | 2 +-
 src/w16select.c                      | 2 +-
 src/w32select.c                      | 2 +-
 test/lisp/net/dbus-tests.el          | 2 +-
 test/lisp/progmodes/python-tests.el  | 4 ++--
 test/manual/cedet/tests/testnsp.cpp  | 2 +-
 test/src/regex-resources/BOOST.tests | 4 ++--
 18 files changed, 21 insertions(+), 21 deletions(-)

diff --git a/doc/lispref/tips.texi b/doc/lispref/tips.texi
index 1826e8f..aaef858 100644
--- a/doc/lispref/tips.texi
+++ b/doc/lispref/tips.texi
@@ -960,7 +960,7 @@ Using multiple top-level code sections has the advantage 
that it
 avoids introducing an additional nesting level but it also means that
 the section named @samp{Code} does not contain all the code, which is
 awkward.  To avoid that, you should put no code at all inside that
-section; that way it can be considered a seperator instead of a
+section; that way it can be considered a separator instead of a
 section heading.
 
 Finally, we recommend that you don't end headings with a colon or any
diff --git a/doc/misc/edt.texi b/doc/misc/edt.texi
index aeb5a26..b0200b4 100644
--- a/doc/misc/edt.texi
+++ b/doc/misc/edt.texi
@@ -841,7 +841,7 @@ keys, as well.  (For example, some people use it to bind 
the VT200
 seldom used back-tick key (@samp{`}) to the function @samp{ESC-prefix}
 so it will behave like an @key{ESC} key.)  The second function,
 @code{edt-bind-gold-key}, is used to bind emacs commands to gold key
-sequences involving alpha-numeric keys, special character keys, and
+sequences involving alphanumeric keys, special character keys, and
 control keys.
 
 The third function, @code{edt-bind-function-key}, is terminal dependent
diff --git a/doc/misc/emacs-mime.texi b/doc/misc/emacs-mime.texi
index 9180b4e..316a1ba 100644
--- a/doc/misc/emacs-mime.texi
+++ b/doc/misc/emacs-mime.texi
@@ -476,7 +476,7 @@ to launch any external programs, set this variable to 
@code{nil} or
 @vindex mm-inline-font-lock
 If non-@code{nil}, inlined parts that support font locking (for
 instance, patches or code snippets) will be font-locked.  This may be
-overriden by callers that have their own ways of enabling/inhibiting
+overridden by callers that have their own ways of enabling/inhibiting
 font locking.
 
 @end table
diff --git a/doc/misc/gnus.texi b/doc/misc/gnus.texi
index a1c8b32..ee20d28 100644
--- a/doc/misc/gnus.texi
+++ b/doc/misc/gnus.texi
@@ -29422,7 +29422,7 @@ collection of @acronym{NOV} lines.
 @item @acronym{NOV}
 @cindex @acronym{NOV}
 @acronym{NOV} stands for News OverView, which is a type of news server
-header which provide datas containing the condensed header information
+header which provide data containing the condensed header information
 of articles.  They are produced by the server itself; in the @code{nntp}
 back end Gnus uses the ones that the @acronym{NNTP} server makes, but
 Gnus makes them by itself for some backends (in particular, @code{nnml}).
diff --git a/etc/compilation.txt b/etc/compilation.txt
index df0b82e..7e40638 100644
--- a/etc/compilation.txt
+++ b/etc/compilation.txt
@@ -153,7 +153,7 @@ Failing Scenarios:
 cucumber foo/cucumber.feature:6 # Scenario: assertion false (Test::Unit)
 cucumber foo/cucumber.feature:9 # Scenario: assertion false (RSpec)
 cucumber foo/cucumber.feature:12 # Scenario: backtrace in step definition
-cucumber foo/cucumber.feature:15 # Scenario: deeep backtrace in step definition
+cucumber foo/cucumber.feature:15 # Scenario: deep backtrace in step definition
 
 5 scenarios (4 failed, 1 undefined)
 5 steps (4 failed, 1 undefined)
diff --git a/lisp/cedet/srecode/fields.el b/lisp/cedet/srecode/fields.el
index e46c582..87c7c68 100644
--- a/lisp/cedet/srecode/fields.el
+++ b/lisp/cedet/srecode/fields.el
@@ -164,7 +164,7 @@ Has virtual :start and :end initializers.")
 
 (cl-defmethod srecode-overlaid-text ((olaid srecode-overlaid) &optional set-to)
   "Return the text under OLAID.
-If SET-TO is a string, then replace the text of OLAID wit SET-TO."
+If SET-TO is a string, then replace the text of OLAID with SET-TO."
   (let* ((ol (oref olaid overlay))
         (start (overlay-start ol)))
     (if (not (stringp set-to))
diff --git a/lisp/completion.el b/lisp/completion.el
index e4a004f..8a4c167 100644
--- a/lisp/completion.el
+++ b/lisp/completion.el
@@ -2041,7 +2041,7 @@ Patched to remove the most recent completion."
 
 ;; All common separators (eg. space "(" ")" """) characters go through a
 ;; function to add new words to the list of words to complete from.
-;; If the character before this was an alpha-numeric then this adds the
+;; If the character before this was an alphanumeric then this adds the
 ;; symbol before point to the completion list (using ADD-COMPLETION).
 
 (defvar completion-separator-chars
diff --git a/lisp/find-file.el b/lisp/find-file.el
index 7e0127d..84d02cb 100644
--- a/lisp/find-file.el
+++ b/lisp/find-file.el
@@ -109,8 +109,8 @@
 ;; file.
 
 ;; CREDITS:
-;; Many thanks go to TUSC Computer Systems Pty Ltd for providing an environ-
-;; ment that made the development of this package possible.
+;; Many thanks go to TUSC Computer Systems Pty Ltd for providing an
+;; environment that made the development of this package possible.
 ;;
 ;; Many thanks also go to all those who provided valuable feedback throughout
 ;; the development of this package:
diff --git a/lisp/international/characters.el b/lisp/international/characters.el
index b7656d9..0b6920c 100644
--- a/lisp/international/characters.el
+++ b/lisp/international/characters.el
@@ -60,7 +60,7 @@ Vietnamese")
 ;; For each group (row) of 2-byte character sets.
 
 (define-category ?A "2-byte alnum
-Alpha-numeric characters of 2-byte character sets")
+Alphanumeric characters of 2-byte character sets")
 (define-category ?C "2-byte han
 Chinese (Han) characters of 2-byte character sets")
 (define-category ?G "2-byte Greek
diff --git a/lisp/menu-bar.el b/lisp/menu-bar.el
index d3e434a..1b3e102 100644
--- a/lisp/menu-bar.el
+++ b/lisp/menu-bar.el
@@ -671,7 +671,7 @@ PROPS are additional properties."
                                         &rest body)
   "Define a menu-bar toggle command.
 See `menu-bar-make-toggle-command', for which this is a
-compatability wrapper.  BODY is passed in as SETTING-SEXP in that macro."
+compatibility wrapper.  BODY is passed in as SETTING-SEXP in that macro."
   (declare (obsolete menu-bar-make-toggle-command "28.1"))
   `(menu-bar-make-toggle-command ,command ,variable ,item-name ,message ,help
                                  ,(and body
diff --git a/lisp/progmodes/perl-mode.el b/lisp/progmodes/perl-mode.el
index 127b24c..7265aee 100644
--- a/lisp/progmodes/perl-mode.el
+++ b/lisp/progmodes/perl-mode.el
@@ -258,7 +258,7 @@
       ;; (or some similar separator), or by one of the special keywords
       ;; corresponding to builtin functions that can take their first arg
       ;; without parentheses.  Of course, that presume we're looking at the
-      ;; *opening* slash.  We can afford to mis-match the closing ones
+      ;; *opening* slash.  We can afford to mismatch the closing ones
       ;; here, because they will be re-treated separately later in
       ;; perl-font-lock-special-syntactic-constructs.
       ((concat perl--syntax-exp-intro-regexp "\\(/\\)")
diff --git a/m4/pkg.m4 b/m4/pkg.m4
index 13a8890..f9075e5 100644
--- a/m4/pkg.m4
+++ b/m4/pkg.m4
@@ -86,7 +86,7 @@ dnl Check to see whether a particular set of modules exists. 
Similar to
 dnl PKG_CHECK_MODULES(), but does not set variables or print errors.
 dnl
 dnl Please remember that m4 expands AC_REQUIRE([PKG_PROG_PKG_CONFIG])
-dnl only at the first occurence in configure.ac, so if the first place
+dnl only at the first occurrence in configure.ac, so if the first place
 dnl it's called might be skipped (such as if it is within an "if", you
 dnl have to call PKG_CHECK_EXISTS manually
 AC_DEFUN([PKG_CHECK_EXISTS],
diff --git a/src/w16select.c b/src/w16select.c
index 5a68162..b56ced4 100644
--- a/src/w16select.c
+++ b/src/w16select.c
@@ -224,7 +224,7 @@ set_clipboard_data (unsigned Format, void *Data, unsigned 
Size, int Raw)
 
   if (!Raw)
     {
-      /* avoid using strchr because it recomputes the length everytime */
+      /* avoid using strchr because it recomputes the length every time */
       while ((dp = memchr (dp, '\n', Size - (dp - dstart))) != 0)
        {
          truelen++;
diff --git a/src/w32select.c b/src/w32select.c
index 9a4b43b..4e5bd6a 100644
--- a/src/w32select.c
+++ b/src/w32select.c
@@ -956,7 +956,7 @@ DEFUN ("w32-get-clipboard-data", Fw32_get_clipboard_data,
 
        truelen = nbytes;
        dst = src;
-       /* avoid using strchr because it recomputes the length everytime */
+       /* avoid using strchr because it recomputes the length every time */
        while ((dst = memchr (dst, '\r', nbytes - (dst - src))) != NULL)
          {
            if (dst[1] == '\n') /* safe because of trailing '\0' */
diff --git a/test/lisp/net/dbus-tests.el b/test/lisp/net/dbus-tests.el
index 759cd10..7ebef5d 100644
--- a/test/lisp/net/dbus-tests.el
+++ b/test/lisp/net/dbus-tests.el
@@ -316,7 +316,7 @@
    (dbus-check-arguments :session dbus--test-service :double "string")
    :type 'wrong-type-argument)
 
-  ;; `:unix-fd'.  UNIX file descriptors are transfered out-of-band.
+  ;; `:unix-fd'.  UNIX file descriptors are transferred out-of-band.
   ;; We do not support this, and so we cannot do much testing here for
   ;; `:unix-fd' being an argument (which is an index to the file
   ;; descriptor in the array of file descriptors that accompany the
diff --git a/test/manual/cedet/tests/testnsp.cpp 
b/test/manual/cedet/tests/testnsp.cpp
index fce707b..b72a44c 100644
--- a/test/manual/cedet/tests/testnsp.cpp
+++ b/test/manual/cedet/tests/testnsp.cpp
@@ -93,7 +93,7 @@ void foo(void) {
     ; // #4# ( "Mumble" "get" )
 }
 
-// What happens if a type your looking for is scoped withing a type,
+// What happens if a type your looking for is scoped within a type,
 // but you are one level into the completion so the originating scope
 // excludes the type of the variable you are completing through?
 // Thanks Martin Stein for this nice example.
diff --git a/test/src/regex-resources/BOOST.tests 
b/test/src/regex-resources/BOOST.tests
index 98fd3b6..756fa00 100644
--- a/test/src/regex-resources/BOOST.tests
+++ b/test/src/regex-resources/BOOST.tests
@@ -93,7 +93,7 @@ aa\) !
 . \0 0 1
 
 ;
-; now move on to the repetion ops,
+; now move on to the repetition ops,
 ; starting with operator *
 - match_default normal REG_EXTENDED
 a* b 0 0
@@ -275,7 +275,7 @@ a(b*)c\1d abbcbbbd -1 -1
 ^(.)\1 abc -1 -1
 a([bc])\1d abcdabbd    4 8 5 6
 ; strictly speaking this is at best ambiguous, at worst wrong, this is what 
most
-; re implimentations will match though.
+; re implementations will match though.
 a(([bc])\2)*d abbccd 0 6 3 5 3 4
 
 a(([bc])\2)*d abbcbd -1 -1



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/test/lisp/progmodes/python-tests.el 
b/test/lisp/progmodes/python-tests.el
index 6b3e636..bc77443 100644
--- a/test/lisp/progmodes/python-tests.el
+++ b/test/lisp/progmodes/python-tests.el
@@ -339,7 +339,7 @@ def func(arg):
     # I don't do much
     return arg
     # This comment is badly indented because the user forced so.
     # At this line python.el wont dedent, user is always right.
 
 comment_wins_over_ender = True
 
@@ -358,7 +358,7 @@ comment_wins_over_ender = True
    ;; The return keyword do make indentation lose a level...
    (should (= (python-indent-calculate-indentation) 0))
    ;; ...but the current indentation was forced by the user.
-   (python-tests-look-at "# At this line python.el wont dedent")
+   (python-tests-look-at "# At this line python.el won't dedent")
    (should (eq (car (python-indent-context)) :after-comment))
    (should (= (python-indent-calculate-indentation) 4))
    ;; Should behave the same for blank lines: potentially a comment.
@@ -339,7 +339,7 @@ def func(arg):
     return arg
     # This comment is badly indented because the user forced so.
-    # At this line python.el wont dedent, user is always right.
+    # At this line python.el won't dedent, user is always right.
 
 comment_wins_over_ender = True